@@ -18,7 +18,7 @@ import uuid
 
 import numpy as np
 import pytest
-from iqm_client.iqm_client import IQMClient, SingleQubitMapping
+from iqm_client import IQMClient
 from mockito import mock, when
 from qiskit import QuantumCircuit
 from qiskit.circuit import Parameter
@@ -54,17 +54,56 @@ def test_run_single_circuit(backend):
     circuit_ser = serialize_circuit(circuit)
     some_id = uuid.uuid4()
     shots = 10
-    when(backend.client).submit_circuits([circuit_ser], [], shots=shots).thenReturn(some_id)
-
-    job = backend.run(circuit, qubit_mapping={}, shots=shots)
+    when(backend.client).submit_circuits([circuit_ser],
+                                         qubit_mapping=None,
+                                         settings=None,
+                                         calibration_set_id=None,
+                                         shots=shots
+                                         ).thenReturn(some_id)
+    job = backend.run(circuit, qubit_mapping=None, shots=shots)
     assert isinstance(job, IQMJob)
     assert job.job_id() == str(some_id)
 
     # Should also work if the circuit is passed inside a list
-    job = backend.run([circuit], qubit_mapping={}, shots=shots)
+    job = backend.run([circuit], qubit_mapping=None, shots=shots)
     assert isinstance(job, IQMJob)
     assert job.job_id() == str(some_id)
 
+
+def test_run_with_non_default_settings(backend):
+    circuit = QuantumCircuit(1, 1)
+    circuit.measure(0, 0)
+    circuit_ser = serialize_circuit(circuit)
+    some_id = uuid.uuid4()
+    shots = 10
+    settings = {'setting1': 5}
+    when(backend.client).submit_circuits([circuit_ser],
+                                        qubit_mapping=None,
+                                        settings=settings,
+                                        calibration_set_id=None,
+                                        shots=shots
+                                        ).thenReturn(some_id)
+
+    backend.run([circuit], qubit_mapping=None, settings=settings, shots=shots)
+
+
+def test_run_with_custom_calibration_set_id(backend):
+    circuit = QuantumCircuit(1, 1)
+    circuit.measure(0, 0)
+    circuit_ser = serialize_circuit(circuit)
+    some_id = uuid.uuid4()
+    shots = 10
+    calibration_set_id = 24
+    when(backend.client).submit_circuits([circuit_ser],
+                                        qubit_mapping=None,
+                                        settings=None,
+                                        calibration_set_id=calibration_set_id,
+                                        shots=shots
+                                        ).thenReturn(some_id)
+
+    backend.run([circuit], qubit_mapping=None, settings=None, calibration_set_id=calibration_set_id, shots=shots)
+
+
 def test_run_circuit_with_qubit_mapping(backend):
     circuit = QuantumCircuit(1, 1)
     circuit.measure(0, 0)
@@ -73,7 +112,9 @@ def test_run_circuit_with_qubit_mapping(backend):
     shots = 10
     when(backend.client).submit_circuits(
         [circuit_ser],
-        [SingleQubitMapping(logical_name='qubit_0', physical_name='QB1')],
+        qubit_mapping={'qubit_0': 'QB1'},
+        settings=None,
+        calibration_set_id=None,
         shots=shots
     ).thenReturn(some_id)
 
@@ -81,6 +122,7 @@ def test_run_circuit_with_qubit_mapping(backend):
     assert isinstance(job, IQMJob)
     assert job.job_id() == str(some_id)
 
+
 def test_run_batch_of_circuits(backend):
     qc = QuantumCircuit(2)
     theta = Parameter('theta')
@@ -94,10 +136,9 @@ def test_run_batch_of_circuits(backend):
     circuits_serialized = [serialize_circuit(circuit) for circuit in circuits]
     when(backend.client).submit_circuits(
         circuits_serialized,
-        [
-            SingleQubitMapping(logical_name='qubit_0', physical_name='QB1'),
-            SingleQubitMapping(logical_name='qubit_1', physical_name='QB2')
-        ],
+        qubit_mapping={'qubit_0': 'QB1', 'qubit_1': 'QB2'},
+        settings=None,
+        calibration_set_id=None,
         shots=shots
     ).thenReturn(some_id)
 
@@ -109,6 +150,7 @@ def test_run_batch_of_circuits(backend):
     assert isinstance(job, IQMJob)
     assert job.job_id() == str(some_id)
 
+
 def test_error_on_empty_circuit_list(backend):
     with pytest.raises(ValueError, match='Empty list of circuits submitted for execution.'):
         backend.run(
@@ -116,3 +158,11 @@ def test_error_on_empty_circuit_list(backend):
             qubit_mapping={},
             shots=42
         )
+
+
+def test_close_client(backend):
+    when(backend.client).close_auth_session().thenReturn(True)
+    try:
+        backend.close_client()
+    except Exception as exc:  # pylint: disable=broad-except
+        assert False, f'backend raised an exception {exc} on .close_client()'
